/*
 * Definitions for libhibr
 *
 * Copyright (C) 2012-2021, Joachim Metz <joachim.metz@gmail.com>
 *
 * Refer to AUTHORS for acknowledgements.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#if !defined( _LIBHIBR_DEFINITIONS_H )
#define _LIBHIBR_DEFINITIONS_H

#include <libhibr/types.h>

#define LIBHIBR_VERSION				20210421

/* The version string
 */
#define LIBHIBR_VERSION_STRING			"20210421"

/* The access flags definitions
 * bit 1        set to 1 for read access
 * bit 2        set to 1 for write access
 * bit 3-8      not used
 */
enum LIBHIBR_ACCESS_FLAGS
{
	LIBHIBR_ACCESS_FLAG_READ		= 0x01,
/* Reserved: not supported yet */
	LIBHIBR_ACCESS_FLAG_WRITE		= 0x02
};

/* The file access macros
 */
#define LIBHIBR_OPEN_READ			( LIBHIBR_ACCESS_FLAG_READ )
/* Reserved: not supported yet */
#define LIBHIBR_OPEN_WRITE			( LIBHIBR_ACCESS_FLAG_WRITE )
/* Reserved: not supported yet */
#define LIBHIBR_OPEN_READ_WRITE			( LIBHIBR_ACCESS_FLAG_READ | LIBHIBR_ACCESS_FLAG_WRITE )

/* The file type definitions
 */
enum LIBHIBR_FILE_TYPES
{
	LIBHIBR_FILE_TYPE_UNDEFINED,
	LIBHIBR_FILE_TYPE_WINDOWS_XP_32BIT,
	LIBHIBR_FILE_TYPE_WINDOWS_XP_64BIT,
	LIBHIBR_FILE_TYPE_WINDOWS_7_32BIT,
	LIBHIBR_FILE_TYPE_WINDOWS_7_64BIT,
};

#define LIBHIBR_FILE_TYPE_WINDOWS_2003_32BIT	LIBHIBR_FILE_TYPE_WINDOWS_XP_32BIT
#define LIBHIBR_FILE_TYPE_WINDOWS_2003_64BIT	LIBHIBR_FILE_TYPE_WINDOWS_XP_64BIT

#endif /* !defined( _LIBHIBR_DEFINITIONS_H ) */

